@@ -19,7 +19,8 @@ class LivekitObserve:
         agent_id="whispey-agent",
         apikey=None, 
         host_url=None, 
-        bug_reports: Union[bool, Dict[str, Any]] = False,
+        bug_reports_enable=False,
+        bug_reports_config: Dict[str, Any] = {},
         enable_otel: bool = False,
     ):
         self.agent_id = agent_id
@@ -32,12 +33,22 @@ class LivekitObserve:
             'turn_sequence': 0
         }
         
-        if bug_reports is not False:
+        if bug_reports_enable:
             self.enable_bug_reports = True
-            if isinstance(bug_reports, dict):
-                config = bug_reports
-            else:
-                config = {}
+            
+            # Default configuration
+            default_config = {
+                'bug_start_command': ['feedback start'],
+                'bug_end_command': ['feedback over'],
+                'response': 'Please tell me the issue?',
+                'continuation_prefix': 'So, as I was saying, ',
+                'fallback_message': 'So, as I was saying,',
+                'collection_prompt': '',
+                'debug': False
+            }
+            
+            # Merge user config with defaults
+            config = {**default_config, **bug_reports_config}
         else:
             self.enable_bug_reports = False
             config = {}
@@ -47,10 +58,15 @@ class LivekitObserve:
         
         self.bug_start_patterns = self._convert_to_regex(start_patterns)
         self.bug_end_patterns = self._convert_to_regex(end_patterns)
+
+        if not start_patterns:
+            start_patterns = ['feedback start']
+        if not end_patterns:
+            end_patterns = ['feedback over']
         
         self.bug_report_response = config.get(
             'response', 
-            "Thanks for reporting that. Please tell me the issue?"
+            "Please tell me the issue?"
         )
         self.continuation_prefix = config.get(
             'continuation_prefix',
@@ -58,94 +74,57 @@ class LivekitObserve:
         )
         self.fallback_message = config.get(
             'fallback_message',
-            "So, as I was saying,"
+            "So, as I was saying, "
         )
         self.collection_prompt = config.get(
             'collection_prompt',
-            "Anything else?"
+            ""
         )
 
+        self.bug_report_debug = config.get('debug', False)
+
     def _update_turn_context(self, turn_id, sequence=None):
         """Update the current turn context"""
         self._current_turn_context = {
             'turn_id': turn_id,
             'turn_sequence': sequence or (self._current_turn_context.get('turn_sequence', 0) + 1)
         }
-    
 
+    def _debug_log(self, message: str):
+        """Debug logging for bug reports when enabled"""
+        if self.bug_report_debug:
+            print(f"🐛 BUG DEBUG: {message}")
+            logger.debug(f"BUG DEBUG: {message}")
 
     def _setup_telemetry(self, session_id):
         if not self.enable_otel:
             return None
         
+        from opentelemetry.sdk.trace import TracerProvider, SpanProcessor
+        import time
+        import uuid
+        import logging
         
-        from opentelemetry.sdk.trace import TracerProvider
-        from opentelemetry.sdk.trace.export import BatchSpanProcessor
-        from opentelemetry.exporter.otlp.proto.http.trace_exporter import OTLPSpanExporter
+        logger = logging.getLogger("whispey-sdk")
         
         tracer_provider = TracerProvider()
 
-        
-        class WhispeySpanProcessor(BatchSpanProcessor):
+        class WhispeySpanCollector(SpanProcessor):
+            """Custom span processor that only collects spans without exporting them"""
+            
             def __init__(self, whispey_instance):
                 self.whispey = whispey_instance
-                exporter = OTLPSpanExporter(
-                    endpoint="https://mp1grlhon8.execute-api.ap-south-1.amazonaws.com/dev/send-call-log",
-                    headers={"Content-Type": "application/json"}
-                )
-                super().__init__(exporter)
 
-            
+            def on_start(self, span, parent_context=None):
+                pass
 
-        
-            def _get_current_turn_id(self):
-                """Get current conversation turn ID"""
-                if hasattr(self.whispey, '_current_turn_context'):
-                    return self.whispey._current_turn_context.get('turn_id')
-                return 'unknown_turn'
-
-            def _get_turn_sequence_number(self):
-                """Get the sequence number of the current turn"""
-                if hasattr(self.whispey, '_current_turn_context'):
-                    return self.whispey._current_turn_context.get('turn_sequence', 0)
-                return 0
-
-            
             def on_end(self, span):
                 # Enhanced request_id extraction
                 request_id = self._extract_request_id_comprehensive(span)
                 
-                if span.attributes:
-                    for key, value in span.attributes.items():
-                        value_str = str(value)
-                        if len(value_str) > 200:
-                            value_str = value_str[:200] + "... [truncated]"
-                        
-                    
-                
-                if span.events:
-                    for event in span.events:
-                        if event.attributes:
-                            for key, value in event.attributes.items():
-                                value_str = str(value)
-                                if len(value_str) > 200:
-                                    value_str = value_str[:200] + "... [truncated]"
-                                print(f"    {key}: {value_str}")
-                        else:
-                            print("    No event attributes")
-                
-                if hasattr(span, 'resource') and span.resource and span.resource.attributes:
-                    for key, value in span.resource.attributes.items():
-                        value_str = str(value)
-                        if len(value_str) > 200:
-                            value_str = value_str[:200] + "... [truncated]"
-                        
-                
-                
                 duration_ns = (span.end_time - span.start_time) if span.start_time and span.end_time else 0
                 duration_ms = duration_ns / 1_000_000
                 
-                
                 comprehensive_span_data = {
                     'name': span.name,
                     'start_time_ns': span.start_time,
@@ -210,20 +189,33 @@ class LivekitObserve:
                         if event.name == 'exception' and event.attributes
                     ],
                     
-                    # Enhanced request_id handling
                     'request_id': request_id,
                     'request_id_source': self._get_request_id_source(span, request_id),
                     'captured_at': time.time(),
                     'sdk_version': '2.1.1',
-                    'conversation_turn_id': self._get_current_turn_id(),  # Add this
+                    'conversation_turn_id': self._get_current_turn_id(),
                     'turn_sequence': self._get_turn_sequence_number(),
                 }
                 
                 self.whispey.spans_data.append(comprehensive_span_data)
-                super().on_end(span)
-            
+
+            def shutdown(self):
+                pass
+
+            def force_flush(self, timeout_millis=30000):
+                return True
+
+            def _get_current_turn_id(self):
+                if hasattr(self.whispey, '_current_turn_context'):
+                    return self.whispey._current_turn_context.get('turn_id')
+                return 'unknown_turn'
+
+            def _get_turn_sequence_number(self):
+                if hasattr(self.whispey, '_current_turn_context'):
+                    return self.whispey._current_turn_context.get('turn_sequence', 0)
+                return 0
+
             def _extract_request_id_comprehensive(self, span):
-                """Enhanced request_id extraction with multiple fallback methods"""
                 span_attrs = span.attributes or {}
                 
                 # Method 1: Direct request_id attributes
@@ -265,9 +257,8 @@ class LivekitObserve:
                     return synthetic_id
                 
                 return None
-            
+
             def _get_request_id_source(self, span, request_id):
-                """Determine how the request_id was obtained"""
                 if not request_id:
                     return 'none'
                 
@@ -296,12 +287,14 @@ class LivekitObserve:
                 
                 return 'synthetic'
         
-        tracer_provider.add_span_processor(WhispeySpanProcessor(self))
+        tracer_provider.add_span_processor(WhispeySpanCollector(self))
 
         from livekit.agents.telemetry import set_tracer_provider
-        set_tracer_provider(tracer_provider, metadata={'session_id': session_id})
-
-
+        try:
+            set_tracer_provider(tracer_provider, metadata={'session_id': session_id})
+        except TypeError:
+            # Fallback for older versions that don't support metadata
+            set_tracer_provider(tracer_provider)
 
     
     def start_session(self, session, **kwargs):
@@ -399,10 +392,6 @@ class LivekitObserve:
                         'id': getattr(item, 'id', None)
                     })
             
-            # Debug: Log what we found in chat_ctx
-            chat_ctx_attrs = [attr for attr in dir(chat_ctx) if not attr.startswith('_')]
-            logger.debug(f"Chat context attributes: {chat_ctx_attrs}")
-            
             # Get system instructions from agent
             system_instructions = getattr(agent, 'instructions', None) or getattr(agent, '_instructions', None)
             
@@ -534,7 +523,7 @@ class LivekitObserve:
                 
                 # Simple STT node with bug report detection
                 async def bug_aware_stt_node(audio_stream, model_settings):
-                    """STT node with bug report detection - Universal await approach"""
+                    """STT node with bug report detection - with proper debug logging"""
                     
                     try:
                         # Get original STT result
@@ -542,7 +531,11 @@ class LivekitObserve:
                             stt_result = agent._whispey_original_stt_node(audio_stream, model_settings)
                         else:
                             from livekit.agents import Agent
-                            stt_result = Agent.default_stt_node(agent, audio_stream, model_settings)
+                            if hasattr(Agent, 'default_stt_node'):
+                                stt_result = Agent.default_stt_node(agent, audio_stream, model_settings)
+                            else:
+                                # Fallback for older versions
+                                stt_result = agent.stt_node(audio_stream, model_settings)
                         
                         # STRATEGY: Always try await first
                         try:
@@ -557,7 +550,7 @@ class LivekitObserve:
                         
                         # Now we should have an async generator in both cases
                         async for event in stt_events:
-                            # Your existing bug detection logic here...
+                            # Extract transcript from event
                             transcript = None
                             if hasattr(event, 'alternatives') and event.alternatives:
                                 transcript = event.alternatives[0].text
@@ -566,24 +559,47 @@ class LivekitObserve:
                             elif isinstance(event, str):
                                 transcript = event
                             
+                            # Skip empty transcripts but still yield the event
                             if not transcript or not transcript.strip():
                                 yield event
                                 continue
                             
                             transcript = transcript.strip()
                             
+                            # Debug logging for STT level processing
+                            if self.bug_report_debug:
+                                print(f"🐛 STT DEBUG: Received transcript: '{transcript}'")
+                                print(f"🐛 STT DEBUG: Current bug mode: {agent._whispey_bug_report_mode}")
+                            
                             # Handle bug reporting cases
                             if agent._whispey_bug_report_mode and self._is_done_reporting(transcript):
+                                if self.bug_report_debug:
+                                    print(f"🐛 STT DEBUG: ✅ Bug end detected: '{transcript}'")
+                                    print(f"🐛 STT DEBUG: Collected {len(agent._whispey_bug_details)} bug messages")
+                                
                                 agent._whispey_bug_report_mode = False
                                 await self._store_bug_report_details(session_id, agent._whispey_bug_details)
                                 agent._whispey_bug_details = []
+                                
+                                if self.bug_report_debug:
+                                    print(f"🐛 STT DEBUG: Sending continuation message")
+                                
                                 await self._repeat_stored_message(session_id, session)
+                                
+                                # Don't yield this event - it's intercepted
                                 continue
-                            
+                                
                             elif not agent._whispey_bug_report_mode and self._is_bug_report(transcript):
+                                if self.bug_report_debug:
+                                    print(f"🐛 STT DEBUG: ✅ Bug start detected: '{transcript}'")
+                                
                                 captured_message = await self._capture_and_store_last_message(session_id)
                                 if not captured_message:
-                                    logger.warning("No message to capture")
+                                    if self.bug_report_debug:
+                                        print(f"🐛 STT DEBUG: ⚠️ No message to capture")
+                                else:
+                                    if self.bug_report_debug:
+                                        print(f"🐛 STT DEBUG: 📝 Captured message: '{captured_message[:50]}...'")
                                 
                                 agent._whispey_bug_report_mode = True
                                 agent._whispey_bug_details = [{
@@ -592,24 +608,44 @@ class LivekitObserve:
                                     'timestamp': __import__('time').time()
                                 }]
                                 
+                                if self.bug_report_debug:
+                                    print(f"🐛 STT DEBUG: Sending bug response: '{self.bug_report_response}'")
+                                
                                 await session.say(self.bug_report_response, add_to_chat_ctx=False)
+                                
+                                # Don't yield this event - it's intercepted
                                 continue
-                            
+                                
                             elif agent._whispey_bug_report_mode:
+                                if self.bug_report_debug:
+                                    print(f"🐛 STT DEBUG: 📥 Collecting bug details: '{transcript}'")
+                                    print(f"🐛 STT DEBUG: Total bug messages so far: {len(agent._whispey_bug_details)}")
+                                
                                 agent._whispey_bug_details.append({
                                     'type': 'bug_details',
                                     'text': transcript,
                                     'timestamp': __import__('time').time()
                                 })
                                 
+                                if self.bug_report_debug:
+                                    print(f"🐛 STT DEBUG: Sending collection prompt: '{self.collection_prompt}'")
+                                
                                 await session.say(self.collection_prompt, add_to_chat_ctx=False)
+                                
+                                # Don't yield this event - it's intercepted
                                 continue
-                            
+                                
                             else:
+                                # Normal processing - yield the event
+                                if self.bug_report_debug:
+                                    print(f"🐛 STT DEBUG: Normal processing: '{transcript}'")
+                                
                                 yield event
                                 
                     except Exception as e:
-                        logger.error(f"STT node wrapper failed: {e}")
+                        if self.bug_report_debug:
+                            print(f"🐛 STT DEBUG: ❌ STT wrapper error: {e}")
+                        
                         # Ultimate fallback: try to use original STT without modification
                         try:
                             if agent._whispey_original_stt_node:
@@ -628,7 +664,8 @@ class LivekitObserve:
                                 yield event
                                 
                         except Exception as fallback_error:
-                            logger.error(f"Fallback STT also failed: {fallback_error}")
+                            if self.bug_report_debug:
+                                print(f"🐛 STT DEBUG: ❌ Fallback STT also failed: {fallback_error}")
                             raise fallback_error
                 
                 # Replace agent's STT node
@@ -755,7 +792,7 @@ class LivekitObserve:
 
 
     
-    async def export(self, session_id, recording_url="", save_telemetry_json=False):
+    async def export(self, session_id, recording_url=""):
         """Export session data to Whispey"""
         
         # Add telemetry spans to the export if available
